@@ -19,6 +19,10 @@
  *          Chris Phelps
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <sys/stat.h>
@@ -26,7 +30,6 @@
 #include <dirent.h>
 #include <string.h>
 #include <time.h>
-#include <config.h>
 #include <libgnome/libgnome.h>
 #include <libgnomeui/libgnomeui.h>
 #include <gdk/gdkx.h>
@@ -100,21 +103,8 @@ static const BonoboUIVerb applet_menu_verbs [] = {
     BONOBO_UI_VERB_END
 };
 
-/* and the XML definition for the popup menu */
-static const char applet_menu_xml [] =
-"<popup name=\"button3\">\n"
-"   <menuitem name=\"RunGTCD\" verb=\"RunGTCD\" _label=\"Run External CD Player\"\n"
-"             pixtype=\"stock\" pixname=\"gtk-cdrom\"/>\n"
-"   <menuitem name=\"Properties\" verb=\"Properties\" _label=\"Properties...\"\n"
-"             pixtype=\"stock\" pixname=\"gtk-properties\"/>\n"
-"   <menuitem name=\"Help\" verb=\"Help\" _label=\"Help\"\n"
-"             pixtype=\"stock\" pixname=\"gtk-help\"/>\n"
-"   <menuitem name=\"About\" verb=\"About\" _label=\"About ...\"\n"
-"             pixtype=\"stock\" pixname=\"gnome-stock-about\"/>\n"
-"</popup>\n";
-
-
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_CDPlayerApplet_Factory",
+			     PANEL_TYPE_APPLET,
                              "CD-Player-Applet",
                              "0",
                               applet_factory,
@@ -142,7 +132,8 @@ applet_fill (PanelApplet *applet)
     int err;
 
     cd = g_new0(CDPlayerData, 1);
-
+    cd->panel.applet = GTK_WIDGET (applet);
+    
     /* the rest of the widgets go in here */
     cdplayer = cd->panel.frame = gtk_frame_new(NULL);
     gtk_frame_set_shadow_type(GTK_FRAME(cdplayer), GTK_SHADOW_IN);
@@ -160,7 +151,6 @@ applet_fill (PanelApplet *applet)
     led_init();
     led_create_widgets(&cd->panel.time, &cd->panel.track_control.display, (gpointer)cd);
 
-    cd->panel.applet = GTK_WIDGET (applet);
     gtk_container_add (GTK_CONTAINER (applet), cdplayer);
 
     /* panel_applet_add_preferences (applet, "/schemas/apps/cdplayer-applet/prefs", NULL); */
@@ -174,10 +164,12 @@ applet_fill (PanelApplet *applet)
     g_signal_connect (applet, "change_orient", G_CALLBACK (applet_change_orient), cd);
     g_signal_connect (applet, "change_size", G_CALLBACK (applet_change_size), cd);
 
-    panel_applet_setup_menu (PANEL_APPLET (applet),
-                             applet_menu_xml,
-                             applet_menu_verbs,
-                             cd);
+    panel_applet_setup_menu_from_file (PANEL_APPLET (applet),
+                                       NULL,
+                                       "GNOME_CDPlayerApplet.xml",
+                                       NULL,
+                                       applet_menu_verbs,
+                                       cd);
 
     component = panel_applet_get_popup_component (PANEL_APPLET (applet));
 
@@ -485,6 +477,21 @@ setup_box(CDPlayerData* cd)
     gtk_widget_show_all(cd->panel.frame);
 }
 
+static gboolean 
+button_press_hack (GtkWidget *w, GdkEventButton *event, gpointer data)
+{
+    PanelApplet *applet = PANEL_APPLET (data);
+    /* Pass the right click to the PanelApplet */
+    if (event->button == 3) {
+    	GTK_WIDGET_CLASS (PANEL_APPLET_GET_CLASS (applet))->
+			  button_press_event (data, event);
+	return TRUE;
+    }
+    
+    return FALSE;
+    
+}
+
 static GtkWidget *
 control_button_factory(gchar * pixmap_data[], GCallback func, CDPlayerData * cd)
 {
@@ -499,6 +506,10 @@ control_button_factory(gchar * pixmap_data[], GCallback func, CDPlayerData * cd)
     image = gtk_image_new_from_pixbuf(pixbuf);
     gtk_widget_show(image);
     gtk_container_add(GTK_CONTAINER(w), image);
+    /* This is a hack to get the right click menu working with buttons
+    ** Should be removed when libpanelapplet is fixed */
+    g_signal_connect (G_OBJECT (w), "button_press_event",
+    		      G_CALLBACK (button_press_hack), cd->panel.applet);
     g_signal_connect(G_OBJECT(w), "clicked",
                      G_CALLBACK(func), cd);
     gtk_widget_show(w);
