@@ -14,6 +14,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 #include <gconf/gconf.h>
@@ -303,6 +307,9 @@ properties_show(PanelApplet *applet, gpointer data)
 	item = gtk_menu_item_new_with_label(_("Cdrom"));
 	gtk_menu_append (GTK_MENU (menu), item);
 	g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(set_widget_sensitivity_false_cb), fbox);
+	item = gtk_menu_item_new_with_label(_("Cd Recorder"));
+	gtk_menu_append (GTK_MENU (menu), item);
+	g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(set_widget_sensitivity_false_cb), fbox);
 	item = gtk_menu_item_new_with_label(_("Zip Drive"));
 	gtk_menu_append (GTK_MENU (menu), item);
 	g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(set_widget_sensitivity_false_cb), fbox);
