@@ -1,7 +1,7 @@
 #ifndef __GWEATHER_APPLET_H_
 #define __GWEATHER_APPLET_H_
 
-/* $Id: gweather-applet.h,v 1.4 2002/01/22 23:15:28 kevinv Exp $ */
+/* $Id: gweather-applet.h,v 1.5 2002/02/03 16:55:53 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -17,10 +17,6 @@
 #include "gweather.h"
 
 G_BEGIN_DECLS
-/*
-extern GtkWidget *gweather_applet;
-extern WeatherInfo *gweather_info;
-*/
 
 extern void gweather_applet_create(GWeatherApplet *gw_applet);
 
