@@ -15,6 +15,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <libbonobo.h>
 #include <libgnome/libgnome.h>
 #include <libgnomeui/libgnomeui.h>
@@ -217,7 +221,7 @@ panel_menu_directory_set_path (PanelMenuEntry *entry, gchar *path)
 		g_print ("monitor successfully installed for %s\n",
 			  directory->path);
 	else
-		g_print ("monitor installation failed for %s\n",
+		g_print ("monitor installation failed for directory %s\n",
 			  directory->path);
 }
 
