@@ -20,8 +20,11 @@
 
 /* If you think this code is a mess, you should see my flat ;) */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <panel-applet.h>
-#include "config.h"
 #include "screenshooter_applet.h"
 
 static void grab_shot (user_preferences * opt, gboolean root);
@@ -1637,17 +1640,6 @@ static const BonoboUIVerb test_applet_menu_verbs [] = {
         BONOBO_UI_VERB_END
 };
 
-static const char test_applet_menu_xml [] =
-	"<popup name=\"button3\">\n"
-	"   <menuitem name=\"Item 1\" verb=\"Props\" _label=\"Properties\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-properties\"/>\n"
-	"   <menuitem name=\"Item 2\" verb=\"Help\" _label=\"Help\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-help\"/>\n"
-	"   <menuitem name=\"Item 3\" verb=\"About\" _label=\"About\"\n"
-	"             pixtype=\"stock\" pixname=\"gnome-stock-about\"/>\n"	
-	"</popup>\n";
-
-
 static gboolean 
 screenshooter_applet_fill (PanelApplet *applet)
 {
@@ -1749,10 +1741,12 @@ screenshooter_applet_fill (PanelApplet *applet)
 	
   gtk_container_add (GTK_CONTAINER (applet), mainbox);
   
-  panel_applet_setup_menu (PANEL_APPLET (applet),
-			   test_applet_menu_xml,
-			   test_applet_menu_verbs,
-			   NULL);
+  panel_applet_setup_menu_from_file (PANEL_APPLET (applet),
+				     NULL,
+				     "GNOME_ScreenshooterApplet.xml",
+				     NULL,
+				     test_applet_menu_verbs,
+				     applet);
 
 
   gtk_widget_show_all (GTK_WIDGET (applet));
@@ -1780,6 +1774,7 @@ screenshooter_applet_factory (PanelApplet *applet,
 }
 
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_ScreenshooterApplet_Factory",
+			     PANEL_TYPE_APPLET,
 			     "Screenshooter applet",
 			     "0",
 			     screenshooter_applet_factory,
